@@ -25,7 +25,7 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2007-2009 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import gtk
+from gi.repository import Gtk
 import locale
 import os
 import sys
@@ -33,20 +33,21 @@ import sys
 import app_prefs
 import braille
 import debug
-import default
-import focus_tracking_presenter
 import input_event
 import keybindings
+import orca
 import orca_gtkbuilder
 import orca_gui_prefs
 import orca_prefs
 import orca_state
 import orca_platform
-import settings
 import speech
 
 from orca_i18n import _  # for gettext support
 
+_scriptManager = getattr(orca, '_scriptManager')
+_settingsManager = getattr(orca, '_settingsManager')
+
 applicationName = None
 appScript = None
 
@@ -72,6 +73,13 @@ class OrcaSetupGUI(orca_gui_prefs.OrcaSetupGUI):
         self.appKeyBindings = None
         self.defKeyBindings = None
 
+    def _getGeneralSettings(self, prefsDict):
+        if prefsDict is None:
+            return orca_gui_prefs.OrcaSetupGUI.\
+                _getGeneralSettings(self, prefsDict)
+
+        return prefsDict
+
     def initAppGUIState(self, thisAppScript):
         """Before we show the GUI to the user we want to remove the
         General tab and gray out the Speech systems and servers 
@@ -90,17 +98,17 @@ class OrcaSetupGUI(orca_gui_prefs.OrcaSetupGUI):
         # in gail or gtk+ (see bug #554002).  Instead, we'll just hide it.
         #
         # self.get_widget("notebook").remove_page(0)
-        self.get_widget("generalVBox").hide()
+        self.get_widget("generalGrid").hide()
 
         self.get_widget("speechSystemsLabel").set_sensitive(False)
         self.get_widget("speechSystems").set_sensitive(False)
         self.get_widget("speechServersLabel").set_sensitive(False)
         self.get_widget("speechServers").set_sensitive(False)
 
-        vbox = self.appScript.getAppPreferencesGUI()
-        if vbox:
-            label = gtk.Label(orca_state.activeScript.app.name)
-            self.get_widget("notebook").append_page(vbox, label)
+        appPage = self.appScript.getAppPreferencesGUI()
+        if appPage:
+            label = Gtk.Label(label=orca_state.activeScript.app.name)
+            self.get_widget("notebook").append_page(appPage, label)
 
     def _createPronunciationTreeView(self, pronunciations=None):
         """Create the pronunciation dictionary tree view for this specific 
@@ -133,12 +141,11 @@ class OrcaSetupGUI(orca_gui_prefs.OrcaSetupGUI):
     def writeUserPreferences(self):
         """Write out the user's application-specific Orca preferences.
         """
-        moduleName = settings.getScriptModuleName(self.app)
+        moduleName = _scriptManager.getModuleName(self.app)
         app_prefs.writePreferences(self.prefsDict, moduleName,
                                    self.appScript, self.keyBindingsModel,
                                    self.pronunciationModel)
-        ftp = focus_tracking_presenter.FocusTrackingPresenter()
-        ftp.loadAppSettings(self.appScript)
+        _settingsManager.loadAppSettings(self.appScript)
 
     def _getAppNameForAttribute(self, attributeName):
         """Converts the given Atk attribute name into the application's
@@ -202,7 +209,7 @@ class OrcaSetupGUI(orca_gui_prefs.OrcaSetupGUI):
 
         # Get the key bindings for the default script.
         #
-        defScript = default.Script(None)
+        defScript = _scriptManager.getDefaultScript()
         self.defKeyBindings = defScript.getKeyBindings()
 
         iterApp = self._createNode(applicationName)
@@ -315,8 +322,6 @@ def showPreferencesUI():
     # The name of the application that currently has focus.
     #
     applicationName = orca_state.activeScript.app.name
-
-    removeGeneralPane = False
     if not orca_state.appOS and not orca_state.orcaOS:
         # Translators: Orca Preferences in this case, is a configuration GUI
         # for allowing users to set application specific settings from within
@@ -332,22 +337,11 @@ def showPreferencesUI():
                          orca_platform.package,
                          "ui",
                          "orca-setup.ui")
-        orca_state.advancedMagUIFile = \
-            os.path.join(orca_platform.prefix,
-                         orca_platform.datadirname,
-                         orca_platform.package,
-                         "ui",
-                         "orca-advanced-magnification.ui")
-        orca_state.advancedMag = \
-          orca_gui_prefs.OrcaAdvancedMagGUI(orca_state.advancedMagUIFile,
-                                   "orcaMagAdvancedDialog", prefsDict)
-        orca_state.advancedMag.init()
-        orca_state.advancedMagDialog = \
-                           orca_state.advancedMag.getAdvancedMagDialog()
 
-        orca_state.appOS = OrcaSetupGUI(orca_state.prefsUIFile,
-                                        "orcaSetupWindow", prefsDict)
-        removeGeneralPane = True
+        orca_state.appOS = \
+            OrcaSetupGUI(orca_state.prefsUIFile, "orcaSetupWindow", prefsDict)
+        orca_state.appOS.initAppGUIState(appScript)
+
         orca_state.appOS.init()
     else:
         if not orca_state.orcaWD:
@@ -365,8 +359,6 @@ def showPreferencesUI():
             warningDialog.show()
         return
 
-    if removeGeneralPane:
-        orca_state.appOS.initAppGUIState(appScript)
     orca_state.appOS.showGUI()
 
 def main():
@@ -374,7 +366,7 @@ def main():
 
     showPreferencesUI()
 
-    gtk.main()
+    Gtk.main()
     sys.exit(0)
 
 if __name__ == "__main__":
